@@ -145,17 +145,7 @@ abstract class Whups_Driver
 
             default:
                 if (strpos($type, 'attribute_') === 0) {
-                    if (is_string($value) && defined('JSON_BIGINT_AS_STRING')) {
-                        $value = json_decode(
-                            $value, true, 512, constant('JSON_BIGINT_AS_STRING')
-                        );
-                    } else {
-                        try {
-                            $value = Horde_Serialize::unserialize(
-                                $value, Horde_Serialize::JSON);
-                        } catch (Horde_Serialize_Exception $e) {
-                        }
-                    }
+                    $value = $this->_json_decode($value);
                     $attribute = substr($type, 10);
                     if (isset($attributes[$attribute])) {
                         $label = $attributes[$attribute];
@@ -200,6 +190,44 @@ abstract class Whups_Driver
         return $history;
     }
 
+    /**
+     * Helper to decode attribute value, which may be a bare scalar value, or
+     * a json encoded structure that may contain large numeric strings that
+     * should not be taken as integers.
+     *
+     * @param string  The value to decode.
+     *
+     * @return mixed  The decoded value.
+     */
+    protected function _json_decode($value)
+    {
+        if (is_string($value) && defined('JSON_BIGINT_AS_STRING')) {
+            $result = json_decode(
+                $value, true, 512, constant('JSON_BIGINT_AS_STRING')
+            );
+            // If we failed above, see if it was a bare scalar value. Note we
+            // need to encode it first to be sure we escape any characters that
+            // need escaping and we properly quote strings.
+            if (!isset($result)) {
+                $result = json_decode(
+                    json_encode($value),
+                    true,
+                    512,
+                    constant('JSON_BIGINT_AS_STRING')
+                );
+            }
+        } else {
+            try {
+                $result = Horde_Serialize::unserialize(
+                    $value, Horde_Serialize::JSON);
+            } catch (Horde_Serialize_Exception $e) {
+                $result = $value;
+            }
+        }
+
+        return $result;
+    }
+
     /**
      */
     public function getQueue($queueId)
